Merge
authorjwilhelm
Tue, 29 Aug 2017 17:17:57 +0200 (2017-08-29)
changeset 47057 6ef313e5ad8d
parent 47056 a78c08ee61c5 (diff)
parent 46935 aff9d4e61eee (current diff)
child 47059 adc5bb7e0131
Merge
common/autoconf/generated-configure.sh
--- a/common/autoconf/flags.m4	Mon Aug 28 21:46:12 2017 +0200
+++ b/common/autoconf/flags.m4	Tue Aug 29 17:17:57 2017 +0200
@@ -1358,7 +1358,7 @@
       $2SOLARIS_LIBM_LIBS="/usr/lib/sparcv9/libm.so.1"
     fi
     $2JVM_LIBS="[$]$2JVM_LIBS -lsocket -lsched -ldl $SOLARIS_LIBM_LIBS -lCrun \
-        -lthread -ldoor -lc -ldemangle -lnsl -lkstat -lrt"
+        -lthread -ldoor -lc -ldemangle -lnsl -lrt"
   elif test "x$OPENJDK_$1_OS" = xmacosx; then
     $2JVM_LIBS="[$]$2JVM_LIBS -lm"
   elif test "x$OPENJDK_$1_OS" = xaix; then
--- a/common/autoconf/hotspot.m4	Mon Aug 28 21:46:12 2017 +0200
+++ b/common/autoconf/hotspot.m4	Tue Aug 29 17:17:57 2017 +0200
@@ -335,8 +335,12 @@
     fi
     INCLUDE_GRAAL="true"
   else
-    # By default enable graal build where AOT is available
-    if test "x$ENABLE_AOT" = "xtrue"; then
+    # By default enable graal build on linux-x64 or where AOT is available.
+    # graal build requires jvmci.
+    if test "x$JVM_FEATURES_jvmci" = "xjvmci" && \
+        (test "x$OPENJDK_TARGET_CPU" = "xx86_64" && \
+         test "x$OPENJDK_TARGET_OS" = "xlinux" || \
+         test "x$ENABLE_AOT" = "xtrue") ; then
       AC_MSG_RESULT([yes])
       JVM_FEATURES_graal="graal"
       INCLUDE_GRAAL="true"
--- a/common/autoconf/generated-configure.sh	Mon Aug 28 21:46:12 2017 +0200
+++ b/common/autoconf/generated-configure.sh	Tue Aug 29 17:17:57 2017 +0200
@@ -5151,7 +5151,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1503949566
+DATE_WHEN_GENERATED=1504027321
 
 ###############################################################################
 #
@@ -52064,7 +52064,7 @@
       SOLARIS_LIBM_LIBS="/usr/lib/sparcv9/libm.so.1"
     fi
     JVM_LIBS="$JVM_LIBS -lsocket -lsched -ldl $SOLARIS_LIBM_LIBS -lCrun \
-        -lthread -ldoor -lc -ldemangle -lnsl -lkstat -lrt"
+        -lthread -ldoor -lc -ldemangle -lnsl -lrt"
   elif test "x$OPENJDK_TARGET_OS" = xmacosx; then
     JVM_LIBS="$JVM_LIBS -lm"
   elif test "x$OPENJDK_TARGET_OS" = xaix; then
@@ -52943,7 +52943,7 @@
       OPENJDK_BUILD_SOLARIS_LIBM_LIBS="/usr/lib/sparcv9/libm.so.1"
     fi
     OPENJDK_BUILD_JVM_LIBS="$OPENJDK_BUILD_JVM_LIBS -lsocket -lsched -ldl $SOLARIS_LIBM_LIBS -lCrun \
-        -lthread -ldoor -lc -ldemangle -lnsl -lkstat -lrt"
+        -lthread -ldoor -lc -ldemangle -lnsl -lrt"
   elif test "x$OPENJDK_BUILD_OS" = xmacosx; then
     OPENJDK_BUILD_JVM_LIBS="$OPENJDK_BUILD_JVM_LIBS -lm"
   elif test "x$OPENJDK_BUILD_OS" = xaix; then
@@ -65798,8 +65798,12 @@
     fi
     INCLUDE_GRAAL="true"
   else
-    # By default enable graal build where AOT is available
-    if test "x$ENABLE_AOT" = "xtrue"; then
+    # By default enable graal build on linux-x64 or where AOT is available.
+    # graal build requires jvmci.
+    if test "x$JVM_FEATURES_jvmci" = "xjvmci" && \
+        (test "x$OPENJDK_TARGET_CPU" = "xx86_64" && \
+         test "x$OPENJDK_TARGET_OS" = "xlinux" || \
+         test "x$ENABLE_AOT" = "xtrue") ; then
       { $as_echo "$as_me:${as_lineno-$LINENO}: result: yes" >&5
 $as_echo "yes" >&6; }
       JVM_FEATURES_graal="graal"